@@ -3,8 +3,9 @@ package Mojolicious::Plugin::I18NUtils;
 # ABSTRACT: provide some helper functions for I18N
 use Mojo::Base 'Mojolicious::Plugin';
 use Time::Piece;
+use CLDR::Number;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 sub register {
     my ($self, $app, $config) = @_;
@@ -12,6 +13,8 @@ sub register {
     $config //= {};
     my $parse_format = $config->{format} // '%Y-%m-%d %H:%M:%S';
 
+    my %objects;
+
     $app->helper( datetime_loc => sub {
         my $c = shift;
         my ($date, $lang) = @_;
@@ -31,6 +34,16 @@ sub register {
 
         return $formatted_date;
     } );
+
+    $app->helper( currency => sub {
+        my ($c, $number, $locale, $currency) = @_;
+
+        $objects{cldr}->{$locale} ||= CLDR::Number->new( locale => $locale );
+        $objects{cur}->{$locale}  ||= $objects{cldr}->{$locale}->currency_formatter( currency_code => $currency );
+
+        my $formatted = $objects{cur}->{$locale}->format( $number );
+        return $formatted;
+    } );
 }
 
 sub _translate {
@@ -170,7 +183,7 @@ Mojolicious::Plugin::I18NUtils - provide some helper functions for I18N
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
